// The program opens a Raw Socket connection to an instrument and queries its identification string
// with a SCPI command '*IDN?'

// Preconditions:
// - R&S VISA or NI VISA or installed
// - Resource string adjusted to fit your instrument physical connection

#include <userint.h>
#include <ansi_c.h>
#include <visa.h>
#include <cvirte.h>

int main (void)
{
        char idnQuery[] = "*IDN?\n"; // LineFeed character at the end - required for SOCKET and Serial connection
        ViStatus status = VI_SUCCESS;
        
        ViUInt32 returnCount = 0;
        ViSession rmHandle, scopeHandle;
        char idnResponse[1024];
        char message[1024];
        
        // Open Resource manager first
        status = viOpenDefaultRM (&rmHandle);

        status = viOpen(rmHandle, "TCPIP::10.212.1.90::5025::SOCKET", VI_NULL, VI_NULL, &scopeHandle);
        status = viClear(scopeHandle); //clear instrument's io buffers
        
        // Linefeed as termination character for reading is necessary for the raw SOCKET and Serial connection
        status = viSetAttribute(scopeHandle, VI_ATTR_TERMCHAR, 10);
        status = viSetAttribute(scopeHandle, VI_ATTR_TERMCHAR_EN, 1);        

        status = viWrite(scopeHandle, (ViBuf)idnQuery, (ViUInt32)strlen(idnQuery), VI_NULL);
        status = viRead(scopeHandle, (ViBuf)idnResponse, 1024, &returnCount);
        idnResponse[returnCount] = 0; //terminate the string properly
        
        sprintf (message, "Hello, I am\n%s", idnResponse);
        MessagePopup ("Hello World", message);
        
    return 0;
}


